Name: ovs-config
Version: 3.3.1
Release: 17%{?dist}
Summary: Configurations for OVM server.
License: GPL
Group: Applications/System
URL: http://www.oracle.com/
Source: %{name}-%{version}.tar.gz
Patch1: ovs-config-initscripts.patch
Patch2: rev65.patch
Patch3: rev72.patch
Patch4: rev80.patch
Patch5: rev86.patch
Patch6: rev93.patch
Patch7: add_mdadm_conf.patch
# End Oracle Patches

BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root
BuildArch: noarch
Requires: module-init-tools
Requires: ntp
Requires: iptables
Requires: iptables-ipv6
Requires: iscsi-initiator-utils
Requires: setup
Requires: ed
Requires: lvm2
Requires: initscripts

%description
Configurations for OVM server.

%prep
%setup -q
%patch1 -p0
%patch2 -p0
%patch3 -p0
%patch4 -p0
%patch5 -p0
%patch6 -p0
%patch7 -p0

%install
rm -rf $RPM_BUILD_ROOT
make DESTDIR=${RPM_BUILD_ROOT} install

%clean
rm -rf $RPM_BUILD_ROOT

%post
if [ $1 -eq 1 ]; then  # For install
    # Remove default ntp servers. (Oracle-Bug: 17628996)
    sed -i '/^server .\.rhel\.pool\.ntp\.org/s//#&/' /etc/ntp.conf

    # Adjust iSCSI session timeout (Oracle-Bug: 14175849)
    sed -i '/^node.session.timeo.replacement_timeout/s/120/10/' /etc/iscsi/iscsid.conf

    # Disable iptables
    chkconfig iptables off
    chkconfig ip6tables off

    # Make sure we have the /etc/motd warning message
    echo -e "Warning: making manual modifications in the management domain\nmight cause inconsistencies between Oracle VM Manager and the server.\n" >/etc/motd

    # Make sure hvc0 and ttyS0 are in /etc/securetty
    for t in hvc0 ttyS0; do
        fgrep -qx $t /etc/securetty || echo $t >>/etc/securetty
    done

    # Disable lvm scanning (Oracle-Bug: 17999985).
    if ! grep -E -q "^[[:space:]]*global_filter" /etc/lvm/lvm.conf >/dev/null; then
        ed -s /etc/lvm/lvm.conf <<EOF
?global_filter?a

    # For OVS, don't even open any device
    global_filter = [ "r/.*/" ]
.
w
q
EOF
        rm -f /etc/lvm/cache/.cache
    fi

    # Show status console (Oracle-Bug: 17614147).
    initctl stop tty TTY=/dev/tty1 >/dev/null 2>&1 || :
    sed -ri '/^ACTIVE_CONSOLES=/s|="?/dev/tty\[1-6\]"?|=/dev/tty[2-6]|' /etc/sysconfig/init
    initctl start tty TTY=/dev/hvc0 >/dev/null 2>&1 || :
    initctl start tty1 >/dev/null 2>&1 || :

    # Disable bridge multicast_snooping (Oracle-Bug: 16746299).
    for f in /etc/sysconfig/network-scripts/ifcfg-*; do
        . $f
        if [ "$TYPE" == "Bridge" -a -z "$BRIDGING_OPTS" ]; then
            echo 'BRIDGING_OPTS="multicast_snooping=0"' >> $f
        fi
    done

    # Fix reboot after upgrading from 3.1.x/3.2.x.
    if ! grep -E -q "^[[:space:]]*l6:6:wait:/etc/rc.d/rc 6" /etc/inittab >/dev/null; then
        echo "l6:6:wait:/etc/rc.d/rc 6" >>/etc/inittab
    fi
fi

%files
%defattr(-,root,root)
%{_sysconfdir}/modprobe.d/ovs.conf
%{_sysconfdir}/sysctl.d/ovs.conf
%{_sysconfdir}/init/tty1.conf
%{_sysconfdir}/mdadm.conf

%changelog
* Wed Mar 19 2014 Cathy Avery <cathy.avery@oracle.com> - 3.3.1-17 
- Added mdadm.conf file that will prevent mdadm on the server from grabing mdraid disks intended for the vms. [bug 18366957]  

* Tue Feb 11 2014 Zhigang Wang <zhigang.x.wang@oracle.com> - 3.3.1-16 
- reserve customized NTP servers 

* Mon Feb 10 2014 Zhigang Wang <zhigang.x.wang@oracle.com> - 3.3.1-15
- reserve customized NTP servers [bug 18224809]

* Mon Feb 10 2014 Zhigang Wang <zhigang.x.wang@oracle.com> - 3.3.1-14 
- fix regular expression: make the space optional 

* Mon Feb 03 2014 Zhigang Wang <zhigang.x.wang@oracle.com> - 3.3.1-13 
- remove smartmon hack [bug 18174983] 

* Mon Feb 03 2014 Zhigang Wang <zhigang.x.wang@oracle.com> - 3.3.1-12
- remove smartmon hack [bug 18174983] 

* Thu Jan 30 2014 Zhigang Wang <zhigang.x.wang@oracle.com> - 3.3.1-11 
- fix serial console cannot login issue 

* Wed Jan 29 2014 Zhigang Wang <zhigang.x.wang@oracle.com> - 3.3.1-10
- fix serial console [bug 18155737]

* Wed Jan 29 2014 Zhigang Wang <zhigang.x.wang@oracle.com> - 3.3.1-9 
- fix configuration file mode 

* Wed Jan 29 2014 Zhigang Wang <zhigang.x.wang@oracle.com> - 3.3.1-8  
- delete unused empty file ovm.conf

* Tue Jan 28 2014 Zhigang Wang <zhigang.x.wang@oracle.com> - 3.3.1-7 
- Add initscripts as required, and
  show status console,
  disable bridge multicast_snooping,
  fix reboot after upgrading from 3.1.x/3.2.x [bug 18148102]  

* Mon Jan 27 2014 Zhigang Wang <zhigang.x.wang@oracle.com> - 3.3.1-6
- Add lvm2 and ed as required, and
  disable lvm scanning [bug 18140934]

* Tue Jan 21 2014 Zhigang Wang <zhigang.x.wang@oracle.com> - 3.3.1-5
- Add smartmontools as required, and
  disable smartmontools email notification [bug 18110889]

* Tue Jan 21 2014 Zhigang Wang <zhigang.x.wang@oracle.com> - 3.3.1-4
- Add setup as required, and
  make sure /etc/motd warning message, and hvc0 and ttyS0 are 
  in /etc/securetty [bug 18110877]

* Thu Dec 19 2013 Zhigang Wang <zhigang.x.wang@oracle.com> - 3.3.1-3
- Add iscsi-initiator-utils as required, and 
  adjust iSCSI session timeout [bug 18071568]

* Thu Dec 19 2013 Zhigang Wang <zhigang.x.wang@oracle.com> - 3.3.1-2
- Add iptables and iptables-ipv6 as required, and
  disable iptables and ip6tables services [bug 18071276]

* Thu Dec 19 2013 John Haxby <john.haxby@oracle.com> - 3.3.1-1
- Initial version.
